# mklibs library size optimization is more useful to smaller images,
# and less useful for bigger images. Also mklibs library optimization
# can break the ABI compatibility, so should not be applied to the
# images which are to be extended or upgraded later.
#This enabled mklibs library size optimization just for the specified image.
#MKLIBS_OPTIMIZED_IMAGES ?= "core-image-minimal"
#This enable mklibs library size optimization will be for all the images.
#MKLIBS_OPTIMIZED_IMAGES ?= "all"

# A list of additional classes to use when building the system
# include 'image-mklibs' to reduce shared library files size for an image
# include 'image-prelink' in order to prelink the filesystem image
# include 'image-swab' to perform host system intrusion detection
# NOTE: if listing mklibs & prelink both, then make sure mklibs is before prelink
USER_CLASSES ?= "image-mklibs image-prelink"

# The following are used to control options related to debugging.
#
# Uncomment this to change the optimization to make debugging easer, at the 
# possible cost of performance.
# DEBUG_BUILD = "1"
#
# Uncomment this to disable the stripping of the installed binaries
# INHIBIT_PACKAGE_STRIP = "1"
#
# Uncomment this to disable the split of the debug information into -dbg files
# INHIBIT_PACKAGE_DEBUG_SPLIT = "1"
#
# When splitting debug information, the following controls the results of the
# file splitting.
#
#  .debug (default):
#    When splitting the debug information will be placed into
#    a .debug directory in the same dirname of the binary produced:
#      /bin/foo -> /bin/.debug/foo
#
#  debug-file-directory:
#    When splitting the debug information will be placed into
#    a central debug-file-directory, /usr/lib/debug:
#      /bin/foo -> /usr/lib/debug/bin/foo.debug
#
#    Any source code referenced in the debug symbols will be copied
#    and made available within the /usr/src/debug directory
#
PACKAGE_DEBUG_SPLIT_STYLE = '.debug'
# PACKAGE_DEBUG_SPLIT_STYLE = 'debug-file-directory'

# Uncomment these to build a package such that you can use gprof to profile it.
# NOTE: This will only work with 'linux' targets, not
# 'linux-uclibc', as uClibc doesn't provide the necessary
# object files.  Also, don't build glibc itself with these
# flags, or it'll fail to build.
#
# PROFILE_OPTIMIZATION = "-pg"
# SELECTED_OPTIMIZATION = "${PROFILE_OPTIMIZATION}"
# LDFLAGS =+ "-pg"

# Set this if you wish to make pkgconfig libraries from your system available 
# for native builds. Combined with extra ASSUME_PROVIDEDs this can allow 
# native builds of applications like oprofileui-native (unsupported feature).
#EXTRA_NATIVE_PKGCONFIG_PATH = ":/usr/lib/pkgconfig"

ENABLE_BINARY_LOCALE_GENERATION = "1"

# The architecture to build SDK items for, by setting this you can build SDK
# packages for architectures other than the host i.e. building i686 packages
# on an x86_64 host.
# Supported values are i686 and x86_64
#SDKMACHINE ?= "i686"

# Set GLIBC_GENERATE_LOCALES to the locales you wish to generate should you not
# wish to perform the time-consuming step of generating all LIBC locales.
# NOTE: If removing en_US.UTF-8 you will also need to uncomment, and set
# appropriate values for IMAGE_LINGUAS and LIMIT_BUILT_LOCALES
# WARNING: this may break localisation!
#GLIBC_GENERATE_LOCALES = "en_GB.UTF-8 en_US.UTF-8"
# See message above as to whether setting these is required
#IMAGE_LINGUAS ?= "en-gb"
#LIMIT_BUILT_LOCALES ?= "POSIX en_GB"

# This value is currently used by PSEUDO to determine if the recipe should
# build both the 32-bit and 64-bit wrapper libraries on a 64-bit build system.
#
# PSEUDO will attempt to determine if a 32-bit wrapper is necessary, but 
# it doesn't always guess properly.  If you have 32-bit executables on 
# your 64-bit build system, you likely want to set this to "0", 
# otherwise you could end up with incorrect file attributes on the 
# target filesystem.
#
# Default to not build 32 bit libs on 64 bit systems, comment this
# out if that is desired
NO32LIBS = "1"

DISTRO = "micro"
INHERIT += "sstate rm_old_work brightsign_source_release sstate_brightsign ccache rm_work"
DISTRO_FEATURES_append = " directfb"

# This was previously the default but oe-core has now switched to ${libdir}/${BPN}.
# We have too many hard-coded references to the old path so let's stick with that one.
libexecdir = "${exec_prefix}/libexec"

# Sink meta-oe below oe-core
BBFILE_PRIORITY_openembedded-layer = "1"

export CCACHE_DIR

LINUXLIBCVERSION = "2.6.39"
OPKGBUILDCMD = "opkg-build"

# This is set to ensure that we have enough room in the partition for
# a few bad blocks and for more to develop in the field. See genparts.sh.
KERNEL_IMAGE_MAXSIZE = "3801088"

# This is set to ensure that we can cope with a few bad blocks already
# in the chip but none to develop in the field. See genparts.sh.
RESCUE_IMAGE_MAXSIZE = "5242880"

export GZIP = "-1"

IMAGE_NAME = "${IMAGE_BASENAME}-${MACHINE}${BS_ALL_SUFFIXES}"
IMAGE_LINK_NAME = "${IMAGE_NAME}"

# If we're using release keys then the path to them will have been via
# BS_RELEASE_KEYS. If it's empty then we're using development
# keys. People who care can inspect this variable to find out whether
# we're doing proper signed releases.
BS_RELEASE_KEYS ?= ""

# The path to the keys we should use for this build.
BS_KEYS_DIR = "${@base_conditional('BS_RELEASE_KEYS', '', '${TOPDIR}/../meta-bcm7425/development-keys', '${BS_RELEASE_KEYS}', d)}"

# The backup public keys are always in the same place. They aren't
# really secret.
BS_BACKUP_KEYS_DIR = "${TOPDIR}/../meta-bcm7425/backup-keys"

BS_ROOTFS_PRIVATE_KEY = "${BS_KEYS_DIR}/${MACHINE}-rootfs-private.pem"
BS_ROOTFS_PUBLIC_KEY = "${BS_KEYS_DIR}/${MACHINE}-rootfs-public.pem"

# By default we don't have a legacy key
BS_KERNEL_LEGACY_PRIVATE_KEY:=""
BS_KERNEL_LEGACY_PUBLIC_KEY:=""

# But Cheetah does have one because early versions of CFE wish the
# kernel to be signed by it.
BS_KERNEL_LEGACY_PRIVATE_KEY_cheetah = "${BS_KEYS_DIR}/${MACHINE}-kernel-legacy-private.pem"
BS_KERNEL_LEGACY_PUBLIC_KEY_cheetah = "${BS_KEYS_DIR}/${MACHINE}-kernel-legacy-public.pem"

BS_KERNEL_PRIVATE_KEY = "UNKNOWN_KERNEL_PRIVATE_KEY"
BS_KERNEL_PUBLIC_KEY = "UNKNOWN_KERNEL_PUBLIC_KEY"
BS_KERNEL_BACKUP_PUBLIC_KEY = "UNKNOWN_BACKUP_PUBLIC_KEY"

BS_KERNEL_PRIVATE_KEY_panther = ""
BS_KERNEL_PUBLIC_KEY_panther = ""
BS_KERNEL_BACKUP_PUBLIC_KEY_panther = ""

BS_KERNEL_PRIVATE_KEY_puma = ""
BS_KERNEL_PUBLIC_KEY_puma = ""
BS_KERNEL_BACKUP_PUBLIC_KEY_puma = ""

# These keys are generated with commands like:
#    openssl genrsa -out cheetah-kernel-private.pem 2048
#    openssl rsa -in cheetah-kernel-private.pem -pubout -out cheetah-kernel-public.pem
BS_KERNEL_PRIVATE_KEY_cheetah = "${@base_conditional('BS_RELEASE_KEYS', '', '', '${BS_KEYS_DIR}/${MACHINE}-kernel-private.pem', d)}"
BS_KERNEL_PUBLIC_KEY_cheetah = "${BS_KEYS_DIR}/${MACHINE}-kernel-public.pem"
BS_KERNEL_BACKUP_PUBLIC_KEY_cheetah = "${BS_BACKUP_KEYS_DIR}/${MACHINE}-kernel-backup-public.pem"

BS_KERNEL_PRIVATE_KEY_tiger = "${@base_conditional('BS_RELEASE_KEYS', '', '', '${BS_KEYS_DIR}/${MACHINE}-kernel-private.pem', d)}"
BS_KERNEL_PUBLIC_KEY_tiger = "${BS_KEYS_DIR}/${MACHINE}-kernel-public.pem"
BS_KERNEL_BACKUP_PUBLIC_KEY_tiger = "${BS_BACKUP_KEYS_DIR}/${MACHINE}-kernel-backup-public.pem"

BS_KERNEL_PRIVATE_KEY_bcm97445 = ""
BS_KERNEL_PUBLIC_KEY_bcm97445 = ""
BS_KERNEL_BACKUP_PUBLIC_KEY_bcm97445 = ""

BSFW_PRIVATE_KEY = "UNKNOWN_BSFW_PRIVATE_KEY"
BSFW_PUBLIC_KEY = "UNKNOWN_BSFW_PUBLIC_KEY"
BSFW_BACKUP_PUBLIC_KEY = "UNKNOWN_BSFW_BACKUP_PUBLIC_KEY"

BSFW_PRIVATE_KEY_panther = ""
BSFW_PUBLIC_KEY_panther = ""
BSFW_BACKUP_PUBLIC_KEY_panther = ""

BSFW_PRIVATE_KEY_puma = ""
BSFW_PUBLIC_KEY_puma = ""
BSFW_BACKUP_PUBLIC_KEY_puma = ""

BSFW_PRIVATE_KEY_cheetah = "${@base_conditional('BS_RELEASE_KEYS', '', '', '${BS_KEYS_DIR}/${MACHINE}-bsfw-private.pem', d)}"
BSFW_PUBLIC_KEY_cheetah = "${BS_KEYS_DIR}/${MACHINE}-bsfw-public.pem"
BSFW_BACKUP_PUBLIC_KEY_cheetah = "${BS_BACKUP_KEYS_DIR}/${MACHINE}-bsfw-backup-public.pem"

BSFW_PRIVATE_KEY_tiger = "${@base_conditional('BS_RELEASE_KEYS', '', '', '${BS_KEYS_DIR}/${MACHINE}-bsfw-private.pem', d)}"
BSFW_PUBLIC_KEY_tiger = "${BS_KEYS_DIR}/${MACHINE}-bsfw-public.pem"
BSFW_BACKUP_PUBLIC_KEY_tiger = "${BS_BACKUP_KEYS_DIR}/${MACHINE}-bsfw-backup-public.pem"

BSFW_PRIVATE_KEY_bcm97445 = ""
BSFW_PUBLIC_KEY_bcm97445 = ""
BSFW_BACKUP_PUBLIC_KEY_bcm97445 = ""
